==> aspose-total-net-23.9.0.tar.gz: aspose-total-net-23.9.0/README.md <==
[Product Page](https://products.aspose.com/total/python-net) | [Docs](https://docs.aspose.com/total/pythonnet/) | [Demos](https://products.aspose.app/total/family) | [Examples](https://aspose.github.io/) | [Download](https://downloads.aspose.com/total/pythonnet) | [Blog](https://blog.aspose.com/category/total/) | [Releases](https://releases.aspose.com/) | [Free Support](https://forum.aspose.com/c/total/7) | [Temporary License](https://purchase.aspose.com/temporary-license)

Aspose.Total for Python via .NET is a collection of powerful yet easy-to-use document processing libraries for Python developers. Create, edit, convert DOC, DOCX, XLSX, XLS, CSV, PPT, PPTX, EML, MSG, 3D, and more formats within Python apps. Render PDF and images with high fidelity, compare documents, protect or encrypt, mail merge, clone slides, work with PowerPoint tables, generate presentations from the database, create custom charts, handle email formats, TNEF attachments, and send/receive emails. Plus, manipulate 3D and CAD files. Aspose.Total for Python via .NET handles a multitude of file formats, including Microsoft Word, PowerPoint, Outlook, OpenOffice, Web, Fixed Layout, Images, and 3D & CAD files. Make Next Generation document processing Apps now!

This release includes the following:

# [Aspose.3D for Python via .NET](https://pypi.org/project/aspose-3d/23.9.0/) (v23.9.0)

Unleash the power of Aspose.3D for Python via .NET, the ultimate Python 3D manipulation high code API. Effortlessly create, process, manipulate, and convert 3D scenes, meshes, and entities - no need for 3rd party software. Enjoy scene creation, animation, geometry, scene hierarchy, triangulate mesh, target camera, 3D plane, shadows, cylinders, conversion, import, and export capabilities. Grow your 3D projects with seamless integration and exceptional 3D control!

# [Aspose.BarCode for Python via .NET](https://pypi.org/project/aspose-barcode-for-python-via-net/23.9/) (v23.9.0)

Aspose.BarCode for Python via .NET is a barcode generation and scanning library for .NET and Python developers. Create barcode images with precise control over size, captions, colors, and font. Generate QR, MicroQR, and Datamatrix barcodes with custom error correction and encoding. Support error correction and checksum for various symbologies. Adjust 2D barcode size and aspect ratio. Customize image border and style. Detect Unicode encoding, hide long codetext, or reduce font size. Colorize barcode, code text, background, border, and caption. Specify size unit in document, inch, millimeter, pixel, or point.

# [Aspose.CAD for Python via .NET](https://pypi.org/project/aspose-cad/23.6/) (v23.6.0)

Aspose.CAD for Python via .NET is ultimate CAD and BIM drawing processing API for .NET and Python developers. Enhance your apps with high-quality conversion and rendering of DWG, DWF, DWFX, DGN, STL, OBJ, CF2, IGES, IFC, DXF, and more formats to PDF and images. No need for AutoCAD&reg; or rendering workflows. Manipulate drawing entities and blocks, select specific layouts and layers, and adjust drawing size before rendering. Exciting new features in Version 23.6 include support for OBJ file format export, HoloLens 2, and AutoCAD Plotter Configuration (PC3) files.

# [Aspose.Cells for Python via .NET](https://pypi.org/project/aspose-cells-python/23.9.0/) (v23.9.0)

Experience the full potential of Aspose.Cells for Python via .NET, our Excel&reg; file handling solution for .NET and Python developers. Create, manipulate, and save Excel&reg; files with ease. Benefit from high-quality format conversion, rendering, and printing capabilities. Effortlessly customize charts, Pivot Tables, and apply advanced formatting. Protect, merge, and parse Excel&reg; sheets seamlessly. Convert charts to images and PDFs while supporting various file formats. Take advantage of the formula calculation engine with support for all Excel functions.

# [Aspose.Diagram for Python via .NET](https://pypi.org/project/aspose-diagram-python/23.9.0/) (v23.9.0)

Improve Visio&reg; file processing with Aspose.Diagram for Python via .NET. Seamlessly create, manipulate, and convert Visio&reg; files, all without Microsoft Office&reg; dependencies. Enjoy features like shape conversion, comment management, and versatile format inter-conversion. Elevate your Python development workflow now!

# [Aspose.Email for Python via .NET](https://pypi.org/project/Aspose.Email-for-Python-via-NET/23.8/) (v23.8.0)

Boost your Python applications with Aspose.Email for Python via .NET, an on-premise API designed to streamline email handling. Send & receive emails with attachments, perform email rendering and format conversions, and download messages from POP3 and IMAP servers. Seamlessly send iCalendar compliant appointments or meetings and work with message storage files. SSL & TLS support included. Uplift your email capabilities now!

# [Aspose.Finance for Python via .NET](https://pypi.org/project/aspose-finance/23.9/) (v23.9.0)

Aspose.Finance for Python via .NET is a powerful API for processing finance-related formats like XBRL, iXBRL, and OFX using Python. It allows creation, manipulation, and conversion of XBRL, iXBRL, and OFX files, providing a comprehensive solution for developers. With features like XBRL and iXBRL creation, format conversion, validation, and more, Aspose.Finance streamlines financial data handling with ease and efficiency.

# [Aspose.Imaging for Python via .NET](https://pypi.org/project/aspose-imaging-python-net/23.9.0/) (v23.9.0)

Aspose.Imaging for Python via .NET is an advanced image processing library. Easily create, load, manipulate, convert, compress images. Supports drawing and graphic primitives. Core features include; image export & conversion, transformations (resize, crop, flip &rotate, etc.), filtering, memory optimization. Handles popular formats like DjVu, DICOM, WebP & DNG, and extends .NET & .NET Core support. Cross-platform; Windows & Linux compatible. Explore powerful features now: create, read, write, draw, process & convert images effortlessly with Aspose.Imaging!

# [Aspose.OCR for Python via .NET](https://pypi.org/project/aspose-ocr-python-net/23.9.1/) (v23.9.1)

Aspose.OCR for Python via .NET is an easy-to-use OCR engine for Python Apps. Recognize text in 28 languages, Latin, Cyrillic & Asian scripts. Extract text from scans, photos, PDFs. Handle blurry, distorted, rotated, noisy images. Preserve original layout, detect paragraphs, lines, single words. Bulk process multipage docs, folders, archives. Identify misspelled words, compare image texts. Simplify OCR tasks with Aspose.OCR!

# [Aspose.PDF for Python via .NET](https://pypi.org/project/aspose-pdf/23.9.0/) (v23.9.0)

Aspose.PDF for Python via .NET is a powerful native library for PDF processing in your applications. Generate, read, convert, and manipulate PDF files without Adobe Acrobat&reg;. Perform form processing, metadata handling, text and page manipulation, annotations management, bookmarks and watermarks, attachments, custom font handling, and more. Supercharge your PDF capabilities via API!

# [Aspose.Slides for Python via .NET](https://pypi.org/project/Aspose.Slides/23.9.0/) (v23.9.0)

Level up your Python programs with Aspose.Slides for Python via .NET - the ultimate Python class library for PowerPoint&reg; & OpenOffice&reg; presentations. No need to install Microsoft PowerPoint&reg; or any 3rd party software. Effortlessly create, clone, and manipulate slides from templates. Master slides, animations, charts, shapes, OLE, VBA Macros, video frames, picture frames, audio frames, encryption, and decryption - all at your fingertips. Elevate your presentation game now!

# [Aspose.Tasks for Python via .NET](https://pypi.org/project/aspose-tasks/23.9.0/) (v23.9.0)

Aspose.Tasks for Python via .NET, a powerful native library for adding MS-Project file processing capabilities to your applications. Easily create, read, convert, and manipulate MS-Project files without Microsoft Project&reg; itself. Perform calculations, manage tasks, resources, and calendars, manipulate views, and handle attachments effortlessly. Enjoy features like export to various image formats, XLSX, HTML, CSV, and PDF, along with support for Oracle Primavera&reg; and Project Server. Supported MS-Project versions include 2003 to 2021. Convert MPP to images, Excel, HTML, CSV, and PDF with ease. Manage tasks, resources, assignments, and customize Gantt Chart view styles.

# [Aspose.Words for Python via .NET](https://pypi.org/project/aspose-words/23.9.0/) (v23.9.0)

Empower your Python applications with Aspose.Words for Python via .NET, an on-premise API for seamless Microsoft Word&reg; document handling. Create, edit, render, and convert Word&reg; files to various formats (PDF, XPS, Raster Image, PCL, EPUB, etc.) effortlessly. Enjoy report generation, data visualization, and a range of document tasks like viewing, merging, splitting, translating, watermarking, and comparison. Level up your document processing now!

# [Aspose.ZIP for Python via .NET](https://pypi.org/project/aspose-zip/23.9.0/) (v23.9.0)

Aspose.ZIP for Python via .NET is a powerful Python API to create, manipulate, extract & protect archive formats - ZIP, BZIP, BZ2 & TAR. Simplify compression/decompression in your Python apps without complex coding. Offers a wide range of features, including archive creation, extraction, encryption (password, AES), and compressing single/multiple files and directories. Secure your files with password or AES encryption. Explore advanced options like appending files to existing archives, Gzip/Bzip2 packing into TAR archives, and creating self-extracting compressed archives.

[Product Page](https://products.aspose.com/total/python-net) | [Docs](https://docs.aspose.com/total/pythonnet/) | [Demos](https://products.aspose.app/total/family) | [Examples](https://aspose.github.io/) | [Download](https://downloads.aspose.com/total/pythonnet) | [Blog](https://blog.aspose.com/category/total/) | [Releases](https://releases.aspose.com/) | [Free Support](https://forum.aspose.com/c/total/7) | [Temporary License](https://purchase.aspose.com/temporary-license)

==> aspose-total-net-23.10.0.tar.gz: aspose-total-net-23.10.0/README.md <==
[Product Page](https://products.aspose.com/total/python-net) | [Docs](https://docs.aspose.com/total/pythonnet/) | [Demos](https://products.aspose.app/total/family) | [Examples](https://aspose.github.io/) | [Download](https://downloads.aspose.com/total/pythonnet) | [Blog](https://blog.aspose.com/category/total/) | [Releases](https://releases.aspose.com/) | [Free Support](https://forum.aspose.com/c/total/7) | [Temporary License](https://purchase.aspose.com/temporary-license)

Aspose.Total for Python via .NET is a collection of powerful yet easy-to-use document processing libraries for Python developers. Create, edit, convert DOC, DOCX, XLSX, XLS, CSV, PPT, PPTX, EML, MSG, 3D, and more formats within Python apps. Render PDF and images with high fidelity, compare documents, protect or encrypt, mail merge, clone slides, work with PowerPoint tables, generate presentations from the database, create custom charts, handle email formats, TNEF attachments, and send/receive emails. Plus, manipulate 3D and CAD files. Aspose.Total for Python via .NET handles a multitude of file formats, including Microsoft Word, PowerPoint, Outlook, OpenOffice, Web, Fixed Layout, Images, and 3D & CAD files. Make Next Generation document processing Apps now!

This release includes the following:

# [Aspose.3D for Python via .NET](https://pypi.org/project/aspose-3d/23.10.0/) (v23.10.0)

Unleash the power of Aspose.3D for Python via .NET, the ultimate Python 3D manipulation high code API. Effortlessly create, process, manipulate, and convert 3D scenes, meshes, and entities - no need for 3rd party software. Enjoy scene creation, animation, geometry, scene hierarchy, triangulate mesh, target camera, 3D plane, shadows, cylinders, conversion, import, and export capabilities. Grow your 3D projects with seamless integration and exceptional 3D control!

```python
pip install aspose-3d==23.10.0
```

# [Aspose.BarCode for Python via .NET](https://pypi.org/project/aspose-barcode-for-python-via-net/23.10/) (v23.10.0)

Aspose.BarCode for Python via .NET is a barcode generation and scanning library for .NET and Python developers. Create barcode images with precise control over size, captions, colors, and font. Generate QR, MicroQR, and Datamatrix barcodes with custom error correction and encoding. Support error correction and checksum for various symbologies. Adjust 2D barcode size and aspect ratio. Customize image border and style. Detect Unicode encoding, hide long codetext, or reduce font size. Colorize barcode, code text, background, border, and caption. Specify size unit in document, inch, millimeter, pixel, or point.

```python
pip install aspose-barcode-for-python-via-net==23.10
```

# [Aspose.CAD for Python via .NET](https://pypi.org/project/aspose-cad/23.9/#description) (v23.9.0)

Aspose.CAD for Python via .NET is ultimate CAD and BIM drawing processing API for .NET and Python developers. Enhance your apps with high-quality conversion and rendering of DWG, DWF, DWFX, DGN, STL, OBJ, CF2, IGES, IFC, DXF, and more formats to PDF and images. No need for AutoCAD&reg; or rendering workflows. Manipulate drawing entities and blocks, select specific layouts and layers, and adjust drawing size before rendering. Exciting new features in Version 23.6 include support for OBJ file format export, HoloLens 2, and AutoCAD Plotter Configuration (PC3) files.

```python
pip install aspose-cad==23.9
```

# [Aspose.Cells for Python via .NET](https://pypi.org/project/aspose-cells-python/23.10.0/) (v23.10.0)

Experience the full potential of Aspose.Cells for Python via .NET, our Excel&reg; file handling solution for .NET and Python developers. Create, manipulate, and save Excel&reg; files with ease. Benefit from high-quality format conversion, rendering, and printing capabilities. Effortlessly customize charts, Pivot Tables, and apply advanced formatting. Protect, merge, and parse Excel&reg; sheets seamlessly. Convert charts to images and PDFs while supporting various file formats. Take advantage of the formula calculation engine with support for all Excel functions.

```python
pip install aspose-cells-python==23.10.0
```

# [Aspose.Diagram for Python via .NET](https://pypi.org/project/aspose-diagram-python/23.10.0/) (v23.10.0)

Improve Visio&reg; file processing with Aspose.Diagram for Python via .NET. Seamlessly create, manipulate, and convert Visio&reg; files, all without Microsoft Office&reg; dependencies. Enjoy features like shape conversion, comment management, and versatile format inter-conversion. Elevate your Python development workflow now!

```python
pip install aspose-diagram-python==23.10.0
```

# [Aspose.Email for Python via .NET](https://pypi.org/project/Aspose.Email-for-Python-via-NET/23.9/) (v23.9.0)

Boost your Python applications with Aspose.Email for Python via .NET, an on-premise API designed to streamline email handling. Send & receive emails with attachments, perform email rendering and format conversions, and download messages from POP3 and IMAP servers. Seamlessly send iCalendar compliant appointments or meetings and work with message storage files. SSL & TLS support included. Uplift your email capabilities now!

```python
pip install Aspose.Email-for-Python-via-NET==23.9
```

# [Aspose.Finance for Python via .NET](https://pypi.org/project/aspose-finance/23.10/) (v23.10.0)

Aspose.Finance for Python via .NET is a powerful API for processing finance-related formats like XBRL, iXBRL, and OFX using Python. It allows creation, manipulation, and conversion of XBRL, iXBRL, and OFX files, providing a comprehensive solution for developers. With features like XBRL and iXBRL creation, format conversion, validation, and more, Aspose.Finance streamlines financial data handling with ease and efficiency.

```python
pip install aspose-finance==23.10
```

# [Aspose.Imaging for Python via .NET](https://pypi.org/project/aspose-imaging-python-net/23.10.0/) (v23.10.0)

Aspose.Imaging for Python via .NET is an advanced image processing library. Easily create, load, manipulate, convert, compress images. Supports drawing and graphic primitives. Core features include; image export & conversion, transformations (resize, crop, flip &rotate, etc.), filtering, memory optimization. Handles popular formats like DjVu, DICOM, WebP & DNG, and extends .NET & .NET Core support. Cross-platform; Windows & Linux compatible. Explore powerful features now: create, read, write, draw, process & convert images effortlessly with Aspose.Imaging!

```python
pip install aspose-imaging-python-net==23.10.0
```

# [Aspose.OCR for Python via .NET](https://pypi.org/project/aspose-ocr-python-net/23.10.1/) (v23.10.1)

Aspose.OCR for Python via .NET is an easy-to-use OCR engine for Python Apps. Recognize text in 28 languages, Latin, Cyrillic & Asian scripts. Extract text from scans, photos, PDFs. Handle blurry, distorted, rotated, noisy images. Preserve original layout, detect paragraphs, lines, single words. Bulk process multipage docs, folders, archives. Identify misspelled words, compare image texts. Simplify OCR tasks with Aspose.OCR!

```python
pip install aspose-ocr-python-net==23.10.1
```

# [Aspose.PDF for Python via .NET](https://pypi.org/project/aspose-pdf/23.10.0/) (v23.10.0)

Aspose.PDF for Python via .NET is a powerful native library for PDF processing in your applications. Generate, read, convert, and manipulate PDF files without Adobe Acrobat&reg;. Perform form processing, metadata handling, text and page manipulation, annotations management, bookmarks and watermarks, attachments, custom font handling, and more. Supercharge your PDF capabilities via API!

```python
pip install aspose-pdf==23.10.0
```

# [Aspose.Slides for Python via .NET](https://pypi.org/project/Aspose.Slides/23.9.0/) (v23.9.0)

Level up your Python programs with Aspose.Slides for Python via .NET - the ultimate Python class library for PowerPoint&reg; & OpenOffice&reg; presentations. No need to install Microsoft PowerPoint&reg; or any 3rd party software. Effortlessly create, clone, and manipulate slides from templates. Master slides, animations, charts, shapes, OLE, VBA Macros, video frames, picture frames, audio frames, encryption, and decryption - all at your fingertips. Elevate your presentation game now!

```python
pip install Aspose.Slides==23.9.0
```

# [Aspose.Tasks for Python via .NET](https://pypi.org/project/aspose-tasks/23.10.0/) (v23.10.0)

Aspose.Tasks for Python via .NET, a powerful native library for adding MS-Project file processing capabilities to your applications. Easily create, read, convert, and manipulate MS-Project files without Microsoft Project&reg; itself. Perform calculations, manage tasks, resources, and calendars, manipulate views, and handle attachments effortlessly. Enjoy features like export to various image formats, XLSX, HTML, CSV, and PDF, along with support for Oracle Primavera&reg; and Project Server. Supported MS-Project versions include 2003 to 2021. Convert MPP to images, Excel, HTML, CSV, and PDF with ease. Manage tasks, resources, assignments, and customize Gantt Chart view styles.

```python
pip install aspose-tasks==23.10.0
```

# [Aspose.Words for Python via .NET](https://pypi.org/project/aspose-words/23.10.0/) (v23.10.0)

Empower your Python applications with Aspose.Words for Python via .NET, an on-premise API for seamless Microsoft Word&reg; document handling. Create, edit, render, and convert Word&reg; files to various formats (PDF, XPS, Raster Image, PCL, EPUB, etc.) effortlessly. Enjoy report generation, data visualization, and a range of document tasks like viewing, merging, splitting, translating, watermarking, and comparison. Level up your document processing now!

```python
pip install aspose-words==23.10.0
```

# [Aspose.ZIP for Python via .NET](https://pypi.org/project/aspose-zip/23.10.0/) (v23.10.0)

Aspose.ZIP for Python via .NET is a powerful Python API to create, manipulate, extract & protect archive formats - ZIP, BZIP, BZ2 & TAR. Simplify compression/decompression in your Python apps without complex coding. Offers a wide range of features, including archive creation, extraction, encryption (password, AES), and compressing single/multiple files and directories. Secure your files with password or AES encryption. Explore advanced options like appending files to existing archives, Gzip/Bzip2 packing into TAR archives, and creating self-extracting compressed archives.

```python
pip install aspose-zip==23.10.0
```

[Product Page](https://products.aspose.com/total/python-net) | [Docs](https://docs.aspose.com/total/pythonnet/) | [Demos](https://products.aspose.app/total/family) | [Examples](https://aspose.github.io/) | [Download](https://downloads.aspose.com/total/pythonnet) | [Blog](https://blog.aspose.com/category/total/) | [Releases](https://releases.aspose.com/) | [Free Support](https://forum.aspose.com/c/total/7) | [Temporary License](https://purchase.aspose.com/temporary-license)
